@@ -2,6 +2,7 @@ import logging
 import glob
 import os
 import sys
+import time
 
 import nymms
 from nymms.daemon import NymmsDaemon
@@ -15,6 +16,7 @@ logger = logging.getLogger(__name__)
 class Reactor(NymmsDaemon):
     def __init__(self):
         self._handlers = {}
+        self._suppress_backend = None
         super(Reactor, self).__init__()
 
     def _list_handler_configs(self, path):
@@ -26,6 +28,7 @@ class Reactor(NymmsDaemon):
 
     def _load_handler(self, handler_name, config, **kwargs):
         enabled = config.pop('enabled', False)
+
         if not enabled:
             logger.debug("Handler %s 'enabled' is not set to true. "
                          "Skipping.", handler_name)
@@ -37,7 +40,7 @@ class Reactor(NymmsDaemon):
             return handler_cls(config)
         except Exception as e:
             logutil.log_exception("Skipping handler %s due to "
-                "unhandled exception:" % (handler_name), logger)
+                "unhandled exception:", handler_name, logger)
             return None
 
     def _load_handlers(self, handler_config_path, **kwargs):
@@ -76,11 +79,29 @@ class Reactor(NymmsDaemon):
     def save_state(self, task_id, result, previous):
         return self._state_backend.save_state(task_id, result, previous)
 
+    def is_suppressed(self, result):
+        """Returns True if we should suppress the given result for event"""
+        if not self._suppress_backend:
+            logger.debug("is_suppressed(): No suppress backend, so returning False")
+            return False
+        suppression_filter = self._suppress_backend.is_suppressed(result.id)
+        if suppression_filter:
+            created_at = time.gmtime(suppression_filter.created_at)
+            timestr = time.strftime("%Y-%m-%d %H:%M:%S UTC", created_at)
+            logger.debug("Suppressed %s with '%s' (%s) created at %s",
+                result.id,
+                suppression_filter.regex,
+                suppression_filter.rowkey,
+                timestr)
+        return suppression_filter
+
     def handle_result(self, result, **kwargs):
         previous_state = self.get_state(result.id)
         for handler_name, handler in self._handlers.iteritems():
             try:
-                handler._process(result, previous_state)
+                # We do suppression AFTER filters, so we have to
+                # pass Reactor to the handler to do that for us
+                handler._process(result, previous_state, self.is_suppressed)
             except Exception:
                 logutil.log_exception("Unhandled %s handler "
                                       "exception:" % (handler_name,), logger)
