@@ -18,19 +18,26 @@ class SchedulerLock(object):
         """ Can be overridden, but a random UUID at launch is probably good
         enough.
         """
-        return uuid.uuid4()
+        return uuid.uuid4().hex
 
-    def _lock_expired(self, timestamp, now):
-        """ Returns the existing lock's timestamp if the lock is expired, or
-        None if there is no existing lock.  If there is a lock and it is not
-        expired then it returns False.
-        """
-        if now - timestamp > self.duration:
+    def lock_expired(self, expiry, now):
+        """ Returns True if the lock is expired, False otherwise.  """
+        if not expiry or int(now) > int(expiry):
             return True
         return False
 
-    def acquire_lock(self):
+    def acquire(self):
         """ Should be overridden and return True or False depending on whether
         it got the lock or not.
         """
-        pass
+        raise NotImplemented
+
+
+class NoOpLock(SchedulerLock):
+    def __init__(self):
+        logger.warning("!!! Using NoOpLock")
+        logger.warning("!!! Do not do this if you are planning to run more ")
+        logger.warning("!!! than one scheduler.""")
+
+    def acquire(self):
+        return True
